/*
 ****************************************************************************
 * Ldap Synchronization Connector provides tools to synchronize
 * electronic identities from a list of data sources including
 * any database with a JDBC connector, another LDAP directory,
 * flat files...
 *
 *                  ==LICENSE NOTICE==
 * 
 * Copyright (c) 2008, LSC Project 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:

 *    * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *     * Neither the name of the LSC Project nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *                  ==LICENSE NOTICE==
 *
 *               (c) 2008 - 2009 LSC Project
 *         Sebastien Bahloul <seb@lsc-project.org>
 *         Thomas Chemineau <thomas@lsc-project.org>
 *         Jonathan Clarke <jon@lsc-project.org>
 *         Remy-Christophe Schermesser <rcs@lsc-project.org>
 ****************************************************************************
 */

package org.lsc.beans;

import java.lang.reflect.InvocationTargetException;
import java.text.ParseException;
import java.util.Date;
import java.util.GregorianCalendar;

import javax.naming.NamingException;

import org.lsc.Configuration;
import org.lsc.objects.Activity;
import org.lsc.utils.CharacterUnacceptedException;
import org.lsc.utils.DateUtils;
import org.lsc.utils.FrenchFilters;

/**
 * @author Sebastien Bahloul <seb@lsc-project.org>
 */
public class activityBean extends AbstractBean implements IBean {

    /** */
	private static final long serialVersionUID = -6697686756350866704L;

	public static activityBean getInstance(Activity aff) throws IllegalAccessException, InvocationTargetException, CharacterUnacceptedException, NamingException {
		activityBean sb = new activityBean();
        AbstractBean.mapper(activityBean.class, sb, aff);
		return sb;
	}
	
	/**
	 * Uid mapping in order to generate the "aliasedObjectName" attribute !
	 * @param se original object
	 * @param destBean object to be completed
	 * @param value the corresponding value
	 * @throws NamingException sometimes ... but not in this method !
	 * @throws CharacterUnacceptedException 
	 */
	public static void mapUid(Activity se, IBean destBean, String value) throws NamingException, CharacterUnacceptedException {
        if(value != null && value.trim().length() != 0) {
            mapString(destBean, "uid", FrenchFilters.filterUid(value));
            mapString(destBean, "aliasedObjectName", "uid=" + FrenchFilters.filterUid(value) + "," + Configuration.DN_PEOPLE + "," + Configuration.DN_REAL_ROOT);
        }
	}

    public static void mapAliasedObjectName(Activity se, IBean destBean, String value) throws NamingException {
        // Do nothing because it is generated through uid map method !
    }
    
    public static void mapEndOfValidity(Activity se, IBean destBean, String value) throws NamingException, ParseException {
    	Date to = null; 
    	if(value != null) {
    		to = DateUtils.parse(value);
    	} else {
    		GregorianCalendar gCalendar = new GregorianCalendar();
    		gCalendar.add(GregorianCalendar.DAY_OF_MONTH, 30);
    		to = gCalendar.getTime();
    	}
    	mapString(destBean, "endOfValidity", DateUtils.format(to));
    }
    
    public void generateDn() throws NamingException {
        throw new RuntimeException("Unavailable generateDn method in this object !");
    }
}
